@@ -27,8 +27,8 @@ def push(tenant, version, conf_path, images=None, equal_tags=None, local_version
         version = version or tenant_conf.get('version')
         equal_tags = equal_tags or tenant_conf.get('equal_tags')
         for image in images:
-            if ';' in image:
-                local, remote = image.split(';')
+            if ':' in image:
+                local, remote = image.split(':')
                 all_remote = remote.split(',')
             else:
                 local, remote = local_version, image
